package Sah::Manual;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-07-28'; # DATE
our $DIST = 'Sah-Manual'; # DIST
our $VERSION = '0.002'; # VERSION

1;
# ABSTRACT: Documentation for Sah

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::Manual - Documentation for Sah

=head1 VERSION

This document describes version 0.002 of Sah::Manual (from Perl distribution Sah-Manual), released on 2021-07-28.

=head1 DESCRIPTION

There are several frameworks that follow the L<Sah> specification, including
L<Data::Sah>, L<Params::Sah>, and a few others, each framework having its own
documentation. This distribution contains additional, mostly cross-framework
documentation.

The documentation is organized around the concept of "four types of
documentation". See L<https://documentation.divio.com/> for more details.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Manual>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Manual>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Manual>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Sah>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
